Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/lccalib/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
src/lccalib/averaging.py | (no class) | 243 | 243 | 0 | 50 | 0 | 0%
src/lccalib/match.py | NearestNeighAssoc | 58 | 58 | 0 | 20 | 0 | 0%
src/lccalib/match.py | NearestNeighAssocHealpy | 48 | 48 | 0 | 16 | 0 | 0%
src/lccalib/match.py | (no class) | 57 | 57 | 0 | 10 | 0 | 0%
src/lccalib/ntuple.py | (no class) | 38 | 38 | 0 | 14 | 0 | 0%
src/lccalib/survey.py | Survey | 1 | 1 | 0 | 0 | 0 | 0%
src/lccalib/survey.py | (no class) | 14 | 14 | 0 | 0 | 0 | 0%
src/lccalib/zp.py | (no class) | 147 | 147 | 0 | 26 | 0 | 0%
/usr/local/lib/python3.9/site-packages/lccalib/__about__.py | (no class) | 1 | 1 | 0 | 0 | 0 | 0%
/usr/local/lib/python3.9/site-packages/lccalib/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
/usr/local/lib/python3.9/site-packages/lccalib/averaging.py | (no class) | 243 | 201 | 0 | 50 | 1 | 15%
/usr/local/lib/python3.9/site-packages/lccalib/match.py | NearestNeighAssoc | 58 | 58 | 0 | 20 | 0 | 0%
/usr/local/lib/python3.9/site-packages/lccalib/match.py | NearestNeighAssocHealpy | 48 | 48 | 0 | 16 | 0 | 0%
/usr/local/lib/python3.9/site-packages/lccalib/match.py | (no class) | 57 | 38 | 0 | 10 | 0 | 28%
/usr/local/lib/python3.9/site-packages/lccalib/ntuple.py | (no class) | 38 | 38 | 0 | 14 | 0 | 0%
/usr/local/lib/python3.9/site-packages/lccalib/survey.py | Survey | 1 | 1 | 0 | 0 | 0 | 0%
/usr/local/lib/python3.9/site-packages/lccalib/survey.py | (no class) | 14 | 14 | 0 | 0 | 0 | 0%
/usr/local/lib/python3.9/site-packages/lccalib/zp.py | (no class) | 147 | 147 | 0 | 26 | 0 | 0%
Total |  | 1213 | 1152 | 0 | 272 | 1 | 4%

No items found using the specified filter.